import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { Typography } from '../index';
import NsBrandWrapper from './NsBrandWrapper';
import NsBrandLogo from './NsBrandLogo';
import NsBgCard from './NsBgCard';

type NsBrandProductCardProps = {
    title?: string;
    brandImageUrl: string;
    backgroundImageUrl: string;
};
const CardContainer = styled(Box)(() => {
    return {
        width: '256px',
        display: 'flex',
        alignItems: 'start',
        justifyContent: 'center',
        position: 'relative',
        flexDirection: 'column',
        '.brand-title': {
            marginTop: '20px',
            fontSize: '20px',
        },
        ':hover': {
            '.brand-title': {
                opacity: '0.7',
            },
        },
    };
});
export default function NsBrandProductCard({ title, brandImageUrl, backgroundImageUrl }: NsBrandProductCardProps) {
    return (
        <CardContainer role="brand-card" component="div" data-testid="brand-product-card">
            <NsBgCard backgroundImageUrl={backgroundImageUrl}>
                <NsBrandWrapper>
                    <NsBrandLogo component="img" image={brandImageUrl} />
                </NsBrandWrapper>
            </NsBgCard>
            {title ? (
                <Typography variant="h3" className="brand-title">
                    {title}
                </Typography>
            ) : null}
        </CardContainer>
    );
}
