import { fireEvent } from '@testing-library/react';
import nuskinTheme from '@nuskin/foundation-theme/src/themes/genome-foundation';
import { NsNavTabComponent } from './NsNavTab';
import { NavTabs } from './types';
import { render } from '../../../test-utils';

const { palette } = nuskinTheme;

const tabs: NavTabs[] = [
    {
        tabName: 'Skin & Beauty',
        tabContnet: <>Skin & Beauty</>,
        color: 'primary',
        activeColor: 'success',
        textVariant: 'h5',
    },
    {
        tabName: 'Beauty Devices',
        tabContnet: <>Beauty Devices</>,
        color: 'primary',
        activeColor: 'success',
        textVariant: 'h5',
    },
    {
        tabName: 'Product Lines',
        tabContnet: <>Product Lines</>,
        color: 'primary',
        activeColor: 'success',
        textVariant: 'h5',
    },
    {
        tabName: 'New & Loved',
        tabContnet: <>New & Loved</>,
        color: 'primary',
        activeColor: 'success',
        textVariant: 'h5',
    },
];

describe('Nav Bar Component', () => {
    it('1. should render Nav Bar Component with variant', () => {
        const { container } = render(
            <NsNavTabComponent tabTitleClassName="text-center" showDrawer className="mb-2" tabs={tabs} />
        );
        const li = container.querySelectorAll('li');
        expect(li.length).toBe(4);
        li.forEach((list, i) => expect(list).toHaveTextContent(tabs[i].tabName));
        expect(container).toBeInTheDocument();
    });

    it('should render and open adn close the drawer', () => {
        const { container, getByTestId } = render(<NsNavTabComponent showDrawer className="mb-2" tabs={tabs} />);
        const li = container.querySelectorAll('li');
        expect(li.length).toBe(4);
        li.forEach((list, i) => expect(list).toHaveTextContent(tabs[i].tabName));
        expect(container).toBeInTheDocument();
        expect(getByTestId('Skin & Beauty-list').firstChild).toHaveStyle(`color: ${palette.primary.main}`);
        fireEvent.mouseOver(getByTestId('Skin & Beauty'));
        expect(getByTestId('nav-drawer')).toBeInTheDocument();
        fireEvent.mouseLeave(getByTestId('Skin & Beauty'));
        expect(getByTestId('nav-drawer-container').firstChild).not.toBeInTheDocument();
    });

    it('should show the underline on hover', () => {
        const { getByTestId } = render(<NsNavTabComponent showDrawer={false} className="mb-2" tabs={tabs} />);
        fireEvent.mouseOver(getByTestId('Skin & Beauty'));
        expect(getByTestId('underline')).toBeInTheDocument();
        expect(getByTestId('underline')).toHaveStyle(`background-color: ${palette.success.main}`);
    });
});
