import { css } from '@emotion/react';
import { styled, GlobalStyles } from '@nuskin/foundation-theme';
import { TypographyProps } from './types';

const variantStyles = {
    h1: 'font-size: 36px; line-height: 44px;',
    h2: 'font-size: 26px; line-height: 32px',
    h3: 'font-size: 22px; line-height: 28px',
    h4: 'font-size: 18px; line-height: 26px',
    h5: 'font-size: 16px; line-height: 22px',
    h6: 'font-size: 14px; line-height: 20px',
    'sub-h-l': 'font-size: 18px; line-height: 22px; text-transform: uppercase; letter-spacing: 0.05em;',
    'sub-h-m': 'font-size: 16px; line-height: 20px; text-transform: uppercase; letter-spacing: 0.05em;',
    'sub-h-s': 'font-size: 14px; line-height: 18px; text-transform: uppercase; letter-spacing: 0.05em;',
    'p-l': 'font-size: 18px; line-height: 24px',
    'p-m': 'font-size: 16px; line-height: 22px',
    'p-s': 'font-size: 14px; line-height: 20px',
    'p-xs': 'font-size: 12px; line-height: 16px',
    'p-xxs': 'font-size: 11px; line-height: 14px',
    CTA: 'font-size: 11px; line-height: 16px',
};

const fontWeightMap = {
    light: 300,
    normal: 400,
    bold: 600,
};

export const StyledTypography = styled.div<TypographyProps>`
    font-family: Inter;
    color: ${({ color = 'primary', theme }) => theme?.palette?.[color]?.main};
    font-weight: ${({ weight = 'normal' }) => fontWeightMap[weight]};
    font-style: ${({ fontStyle }) => fontStyle};
    ${({ variant = 'h1' }) => variantStyles[variant]};
    text-decoration-line: ${({ decoration }) => decoration};
`;

export const GlobalFontInter = () => (
    <GlobalStyles
        styles={css`
            @import url('https://fonts.googleapis.com/css2?family=Inter');
            body {
                font-family: 'Inter', sans-serif;
            }
        `}
    />
);
